# Analysis script for Gott et al. 'Chronological age, biological age, and individual variation in the stress response: A follow-up study'
###Head - run me####
# Packages
library(psych)
library(lme4)
library(ggplot2)
library(metafor)
library(irr)
library(afex)
library(dplyr)
library(tidyr)

# Get data
a1=read.csv("age.point1.csv")
a2=read.csv("age.point2.csv")
total=merge(a1, a2, by="BirdID",all.x=T, all.y=T)
# End head # 

###Descriptive stats#####
describe(a1)
xtabs(~(a1$Cort15>a1$Cort30))
describe(a2)
xtabs(~(a2$Cort15>a2$Cort30))
t.test(total$Cort0.y, total$Cort0.x, paired=T)
t.test(total$Cort15.y, total$Cort15.x, paired=T)
t.test(total$Cort30.y, total$Cort30.x, paired=T)
t.test(total$PeakCort.y, total$PeakCort.x, paired=T)
t.test(total$DeltaCort.y, total$DeltaCort.x, paired=T)

# Figure 1
a1.sub=select(a1, BirdID, Cort0, Cort15, Cort30)
a1.long=reshape(a1.sub, idvar="BirdID", direction="long", varying=list(2:4), times=c(0, 15, 30), v.names="Cort")
a2.sub=select(a2, BirdID, Cort0, Cort15, Cort30)
a2.long=reshape(a2.sub, idvar="BirdID", direction="long", varying=list(2:4), times=c(0, 15, 30), v.names="Cort")
a.long=rbind(a1.long, a2.long)
a.long$experiment="Age point 1"
a.long$experiment[94:183]="Age point 2"
png("fig1.png", res=300, units="in", width=6, height=4)
fig=ggplot(a.long, aes(x=time, y=Cort, group=BirdID)) + 
  geom_line(colour="darkred") + 
  theme_bw() + 
  facet_wrap(~experiment) + 
  ylab("CORT (ng/ml)") +
  xlab("Time from onset of stressor (mins)") +
  scale_x_continuous(breaks=c(0, 15, 30))
fig
dev.off()

###Familial and individual consistency####
# Variance components estimation
# Age point 1
m1=lmer(Cort0~ (1|NatalNest), data=a1, REML=T)
summary(m1)
2.901/(1.359+2.901)
# 68%
m2=lmer(PeakCort~ (1|NatalNest), data=a1, REML=T)
summary(m2)
25.09/(25.09+50.13)
# 33%
m3=lmer(DeltaCort~ (1|NatalNest), data=a1, REML=T)
summary(m3)
0/(0+49)
# 0

# Age point 2
m1b=lmer(Cort0~ (1|NatalNest), data=a2, REML=TRUE)
summary(m1b)
0.04363/(0.04363+2.31145)
#1.8%
m2b=lmer(PeakCort~ (1|NatalNest), data=a2, REML=TRUE)
summary(m2b)
7.261/(7.261+25.516)
#  22%
m3b=lmer(DeltaCort~ (1|NatalNest), data=a2, REML=TRUE)
summary(m3b)
10.39/(10.39+15.51)
# 40%

# Put these estimates into a data frame to make the figure
Variable=rep(c(rep("Baseline", times=2), rep("Peak", times=2), rep("Delta", times=2)), times=2)
Component=rep(c("Natal family", "Residual"), times=6)
Experiment=c(rep("Age point 1", times=6), rep("Age point 2", times=6))
Values=c(
  2.901/(1.359+2.901),
  1.359/(1.359+2.901),
  25.09/(25.09+50.13),
  50.13/(25.09+50.13),
  0, 
  49/49,
  0.04363/(0.04363+2.31145), 
  2.31145/(0.04363+2.31145), 
  7.261/(7.261+25.516), 
  25.516/(7.261+25.516), 
  10.39/(10.39+15.51), 
  15.51/(10.39+15.51))
  
fig2data=data.frame(Variable, Component, Experiment, Values)
fig2=ggplot(fig2data, aes(x=Variable, y=Values, fill=Component)) + 
  geom_bar(stat="identity", colour="black") + 
  scale_x_discrete(limits=c("Baseline", "Peak", "Delta")) +
  scale_fill_manual(values=c("black", "white")) +
  theme_bw() + 
  ylab("Proportion of variation") +
  xlab("CORT variable") + 
  facet_wrap(~Experiment)
fig2
png("Figure2.png", res=300, units="in", width=6, height=3)
print(fig2)
dev.off()

# Individual consistency between age 1 and age 2 measures
icc(data.frame(total$Cort0.x, total$Cort0.y))
icc(data.frame(total$PeakCort.x, total$PeakCort.y))
icc(data.frame(total$DeltaCort.x, total$DeltaCort.y))
icc(data.frame(total$Cort15.x, total$Cort15.y))
icc(data.frame(total$Cort30.x, total$Cort30.y))

### Replication of Andrews et al. ####
# Unstandardized analyses
# Age point 1
# baseline
mixed(Cort0 ~ DeltaTL + (1|NatalNest), data=subset(a1, !is.na(DeltaTL)), method="LRT")
summary(mixed(Cort0 ~ DeltaTL + (1|NatalNest), data=subset(a1, !is.na(DeltaTL)), method="LRT"))

# peak
mixed(PeakCort~Cort0 + DeltaTL + (1|NatalNest), data=subset(a1, !is.na(DeltaTL)), method="LRT")
summary(mixed(PeakCort~Cort0 + DeltaTL + (1|NatalNest), data=subset(a1, !is.na(DeltaTL)), method="LRT"))

# delta
mixed(DeltaCort~Cort15 + DeltaTL + (1|NatalNest), data=subset(a1, !is.na(DeltaTL)), method="LRT")
summary(mixed(DeltaCort~Cort15 + DeltaTL + (1|NatalNest), data=subset(a1, !is.na(DeltaTL)), method="LRT"))

# Age point 2
# baseline
mixed(Cort0 ~ DeltaTL + (1|NatalNest), data=subset(a2, !is.na(DeltaTL)), method="LRT")
summary(mixed(Cort0 ~ DeltaTL + (1|NatalNest), data=subset(a2, !is.na(DeltaTL)), method="LRT"))

# peak
mixed(PeakCort~Cort0 + DeltaTL + (1|NatalNest), data=subset(a2, !is.na(DeltaTL)), method="LRT")
summary(mixed(PeakCort~Cort0 + DeltaTL + (1|NatalNest), data=subset(a2, !is.na(DeltaTL)), method="LRT"))

# delta
mixed(DeltaCort~Cort15 + DeltaTL + (1|NatalNest), data=subset(a2, !is.na(DeltaTL)), method="LRT")
summary(mixed(DeltaCort~Cort15 + DeltaTL + (1|NatalNest), data=subset(a2, !is.na(DeltaTL)), method="LRT"))

###Meta analysis####
# Get comparable standardized parameter estimates to those in 2012 and 2013
# baseline
m1a=lmer(scale(Cort0)~scale(DeltaTL) + (1|NatalNest), REML=FALSE, data=a1)
m1b=lmer(scale(Cort0)~scale(DeltaTL) + (1|NatalNest), REML=FALSE, data=a2)
#peak
m2a=lmer(scale(PeakCort)~scale(DeltaTL) + scale(Cort0) + (1|NatalNest), REML=FALSE, data=a1)
m2b=lmer(scale(PeakCort)~scale(DeltaTL) +  scale(Cort0) + (1|NatalNest), REML=FALSE, data=a2)
# delta
m3a=lmer(scale(DeltaCort)~scale(DeltaTL) + scale(Cort15) + (1|NatalNest), REML=FALSE, data=a1)
m3b=lmer(scale(DeltaCort)~scale(DeltaTL) +  scale(Cort15) + (1|NatalNest), REML=FALSE, data=a2)

# Meta-analytic data including 2012 and 2013 cohorts
cohort = c("2012 cohort", "2013 cohort", "2014 cohort, time 1", "2014 cohort, time 2")
base.effect = c(-0.0010855,0.08077, summary(m1a)$coefficients[2, 1], summary(m1b)$coefficients[2, 1])
base.se = c(0.2139518,0.19004, summary(m1a)$coefficients[2, 2], summary(m1b)$coefficients[2, 2])
peak.effect = c(0.47586,0.08453, summary(m2a)$coefficients[2, 1], summary(m2b)$coefficients[2, 1])
peak.se = c(0.17249,0.19131, summary(m2a)$coefficients[2, 2], summary(m2b)$coefficients[2, 2])
delta.effect = c(0.42041,0.43480, summary(m3a)$coefficients[2, 1], summary(m3b)$coefficients[2, 1])
delta.se = c(0.19150,0.17109, summary(m3a)$coefficients[2, 2], summary(m3b)$coefficients[2, 2])
meta = data.frame(cohort, base.effect, base.se, peak.effect,peak.se,delta.effect,delta.se)
meta1 = meta[1:3, ]
meta2=meta[c(1, 2, 4), ]

effect=c(-0.0010855,0.08077, summary(m1a)$coefficients[2, 1], summary(m1b)$coefficients[2, 1], 
         0.47586,0.08453, summary(m2a)$coefficients[2, 1], summary(m2b)$coefficients[2, 1], 
         c(0.42041,0.43480, summary(m3a)$coefficients[2, 1], summary(m3b)$coefficients[2, 1]))
se=c(0.2139518,0.19004, summary(m1a)$coefficients[2, 2], summary(m1b)$coefficients[2, 2], 
     0.17249,0.19131, summary(m2a)$coefficients[2, 2], summary(m2b)$coefficients[2, 2], 
     0.19150,0.17109, summary(m3a)$coefficients[2, 2], summary(m3b)$coefficients[2, 2])
cohorts=rep(c("2012 cohort", "2013 cohort", "2014 cohort, age 1", "2014 cohort, age 2"), times=3)
outcomes=c(rep("Baseline", times=4), rep("Peak", times=4), rep("Delta",times=4))
meta.long=data.frame(cohorts, outcomes, effect, se)

# Meta-analyses
# Baseline
m.base.1 = rma(yi = base.effect, sei = base.se, measure = "GEN", method = "FE", data = meta1, weighted = FALSE)
m.base.2 = rma(yi = base.effect, sei = base.se, measure = "GEN", method = "FE", data = meta2, weighted = FALSE)
# peaks
m.peak.1 = rma(yi = peak.effect, sei = peak.se, measure = "GEN", method = "FE", data = meta1, weighted = F)
m.peak.2 = rma(yi = peak.effect, sei = peak.se, measure = "GEN", method = "FE", data = meta2, weighted = F)
# deltacort
m.delta.1 = rma(yi = delta.effect, sei = delta.se, measure = "GEN", method = "FE", data = meta1, weighted = F)
m.delta.2 = rma(yi = delta.effect, sei = delta.se, measure = "GEN", method = "FE", data = meta2, weighted = F)

### Make a combined forest plot
png("fig3.png", res=300, width=4, height=6, units="in")
par(font=1)
forest.default(x=meta.long$effect, sei=meta.long$se, slab=meta.long$cohort, 
               rows=c(18:15, 11:8, 4:1), ylim=c(-1, 22), cex=0.75, xlab=expression(paste("Standardized ", beta)), 
               psize=1)
par(font=4)
text(-1.8, c(19,12,5), pos=4, c("Baseline CORT",
                               "Peak CORT",
                               "Delta CORT"), cex=0.75)
addpoly(m.base.1, row=14, cex=0.5, mlab="")
addpoly(m.base.2, row=13, cex=0.5, mlab="")
addpoly(m.peak.1, row=7, cex=0.5, mlab="")
addpoly(m.peak.2, row=6, cex=0.5, mlab="")
addpoly(m.delta.1, row=0, cex=0.5, mlab="")
addpoly(m.delta.2, row=-1, cex=0.5, mlab="")
dev.off()

### Effects of developmental treatment #####
# Note here that treatment variables are automatically contrast-coded by afex
# Age point 1
# Baseline CORT
mixed(Cort0 ~ Amount*Effort + (1|NatalNest), data=a1, method="LRT")
summary(mixed(Cort0 ~ Amount*Effort + (1|NatalNest), data=a1, method="LRT"))
# Peak CORT
mixed(PeakCort ~ Cort0 + Amount*Effort + (1|NatalNest), data=a1, method="LRT")
summary(mixed(PeakCort ~ Cort0 + Amount*Effort + (1|NatalNest), data=a1, method="LRT"))
# Delta CORT
mixed(DeltaCort ~ Cort15 + Amount*Effort + (1|NatalNest), data=a1, method="LRT")
summary(mixed(DeltaCort ~ Cort15 + Amount*Effort + (1|NatalNest), data=a1, method="LRT", return="merMod"))

# Age point 2
# Baseline CORT
mixed(Cort0 ~ Amount*Effort + (1|NatalNest), data=a2, method="LRT")
summary(mixed(Cort0 ~ Amount*Effort + (1|NatalNest), data=a2, method="LRT", return="merMod"))
# Peak CORT
mixed(PeakCort ~ Cort0 + Amount*Effort + (1|NatalNest), data=a2, method="LRT")
summary(mixed(PeakCort ~ Cort0 + Amount*Effort + (1|NatalNest), data=a2, method="LRT"))
# Delta CORT
mixed(DeltaCort ~ Cort15 + Amount*Effort + (1|NatalNest), data=a2, method="LRT")
summary(mixed(DeltaCort ~ Cort15 + Amount*Effort + (1|NatalNest), data=a2, method="LRT"))

# Visualize the significant effects (not included in paper)
boxplot(a1$DeltaCort ~ a1$Effort)
boxplot(a2$DeltaCort ~ a2$Treatment)
a1$resdc=residuals(lm(a1$DeltaCort ~ a1$Cort15))
boxplot(a1$resdc ~ a1$Treatment)
a2$resdc=residuals(lm(a2$DeltaCort ~ a2$Cort15))
boxplot(a2$resdc ~ a2$Treatment)

###Power simulations####
# Note that this simulation ignores random effect structure
# Which is probably ok since deltaTL not very familial
power.sim<-function(true.effect.size, k=10000, n=27) {
  significant=0
  direction=0
  wrong=0
 for (i in 1:k) {
  x=rnorm(n)
  y=true.effect.size*x + sqrt(1-true.effect.size^2)*rnorm(n)
  m=lm(y~x)
  if (summary(m)$coefficients[2, 4]<0.05 & summary(m)$coefficients[2, 3]>0) {significant=significant+1}
  if (summary(m)$coefficients[2, 4]>=0.05 & summary(m)$coefficients[2, 3]>0) {direction=direction+1}
  if (summary(m)$coefficients[2, 3]<=0) {wrong=wrong+1}
 }
  answer=c(significant/k, direction/k, wrong/k)
  names(answer)=c("Significant", "Same direction", "Other direction")
  return(answer)
}
power.sim(0.28)
power.sim(0.43)
